@@ -1,7 +1,7 @@
 /*
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2016 Rafael Fonseca
- * Copyright © 2016 Red Hat, Inc.
+ * Copyright © 2016 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -219,8 +219,8 @@ photos_done_notification_class_init (PhotosDoneNotificationClass *class)
   g_object_class_install_property (object_class,
                                    PROP_ITEM,
                                    g_param_spec_pointer ("item",
-                                                         "PhotosBaseItem",
-                                                         "the edited PhotosBaseItem",
+                                                         "PhotosBaseItem instance",
+                                                         "The edited PhotosBaseItem",
                                                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
 }
 
